@@ -1,6 +1,6 @@
-__all__ = ["VERSION", "get_version", "__version__"]
+__all__ = ["VERSION", "get_version", "__version__", "default_app_config"]
 
-VERSION = (1, 57, 2, "final", 0)
+VERSION = (1, 62, 0, "final", 0)
 
 
 def get_version():
@@ -26,3 +26,5 @@ __version__ = get_version()
 # TODO: remove this by reworking ldt dependencies
 #from django.db.models.loading import get_models
 #_ = get_models()
+
+default_app_config = 'ldt.apps.LdtAppConfig'
